package com.yunzhi.marketing.xlk.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.common.StringUtils;
import com.yunzhi.marketing.xlk.entity.Institution;
import com.yunzhi.marketing.xlk.service.IInstitutionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
    * 组织结构表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2021-06-22
 */
@RestController
@RequestMapping("/api")
@Api(value = "组织结构相关接口", tags = "xlk-组织结构相关接口")
public class InstitutionController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(InstitutionController.class);

    @Autowired
    public IInstitutionService iInstitutionService;


    /**
     * 分页查询列表
     * @param institutionId
     * @return
     */
    @ApiOperation(value = "admin-组织机构列表查询", notes = "admin-组织机构列表查询")
    @RequestMapping(value="/admin/institution/list",method= RequestMethod.GET)
    public ResponseBean institutionList(@RequestParam(value ="institutionId",required = false) String institutionId,
                                        @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            LambdaQueryWrapper<Institution> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.eq(Institution::getOrgId,getOrgId(request));
            if (StringUtils.isEmpty(institutionId)){
                queryWrapper.eq(Institution::getType,1);
            }else {
                Institution institution = iInstitutionService.getById(institutionId);
                queryWrapper.eq(Institution::getType,institution.getType() + 1);
                queryWrapper.likeLeft(Institution::getInstitutionCode,institution.getInstitutionCode());
            }
            queryWrapper.orderByDesc(Institution::getCreateDate);

            List<Institution> list = iInstitutionService.list(queryWrapper);
            responseBean.addSuccess(list);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("institutionList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param institution 实体对象
     * @return
     */
    @ApiOperation(value = "admin-组织机构列表查询", notes = "admin-组织机构列表查询")
    @RequestMapping(value="/institution",method= RequestMethod.POST)
    public ResponseBean institutionAdd(@RequestBody Institution institution, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iInstitutionService.save(institution)){
                responseBean.addSuccess(institution);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("institutionAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ApiOperation(value = "", notes = "")
    @ResponseBody
    @RequestMapping(value="/institution/{id}", method= RequestMethod.DELETE)
    public ResponseBean institutionDelete(@PathVariable String id, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iInstitutionService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("institutionDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param institution 实体对象
     * @return
     */
    @ApiOperation(value = "", notes = "")
    @RequestMapping(value="/institution/{id}",method= RequestMethod.PUT)
    public ResponseBean institutionUpdate(@PathVariable String id,
                                          @RequestBody Institution institution, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iInstitutionService.updateById(institution)){
                responseBean.addSuccess(institution);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("institutionUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @ApiOperation(value = "", notes = "")
    @RequestMapping(value="/institution/{id}",method= RequestMethod.GET)
    public ResponseBean institutionGet(@PathVariable String id, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iInstitutionService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("institutionDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
